/*
 * UNPUBLISHED PROPRIETARY INFORMATION
 * Copyright (c) 2007-2008 Sentilla Corporation
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Sentilla Corporation ("Confidential Information"). Disclosure of this
 * Confidential Information is prohibited, and its use shall be in
 * compliance with terms of the license agreement with Sentilla Corporation.
 */

import java.io.Serializable;

import com.sentilla.net.Mac64Address;
import com.sentilla.net.Receiver;
import com.sentilla.net.ReceiverDriver;
import com.sentilla.net.Sender;
import com.sentilla.net.SenderDriver;
import com.sentilla.system.Leds;
import com.sentilla.system.LedsDriver;

/**
 * A simple ping application.  A host can send a message to a mote, and the
 * mote will echo the received message back to the host.
 *
 * Responds to messages from the corresponding ClientPing host application.
 *
 * @author <a href="mailto:info@sentilla.com">Sentilla Corporation</a>
 */
public class MotePing {

    /**
     * PingMsg is a container for recieving Ping messages from a host.
     * The field in the class is the data received from the network for this
     * data type.
     */
    public static class PingMsg implements Serializable
    {
        /**
         * A unique counter value for each Ping message.
         */
        public int count;

    }

    /**
     * ReplyMsg is a container for sending responses to Ping messages to a host.
     * The fields in the class are the data sent using the network for this
     * data type.
     */
    public static class ReplyMsg implements Serializable
    {
        /**
         * The Id of the mote responding to a Ping message.
         */
        public long id;

        /**
         * The count received from a Ping that is sent back to the host to
         * acknowledge receipt of the Ping message.
         */
        public int count;
    }

    public static void motemain() throws Exception {
        // Use the LedsDriver factory to create an Leds instance
        Leds leds = LedsDriver.create();

        // Create a protocol sender object that uses the CC2420 radio
        Sender sender = SenderDriver.create("local");

        // Construct message object containers for data that will be sent or received
        PingMsg ping_msg = new PingMsg();
        ReplyMsg reply_msg = new ReplyMsg();

        // Create a protocol receiver object that receives objects
        // that are of the same type as the ping_msg class
        Receiver recv = ReceiverDriver.create(PingMsg.class);

        // Get the local node's 64-bit MAC address
        reply_msg.id = Mac64Address.getLocalAddress().longValue(); 

        while(true) {
            // Block until a PingMsg object is received
            ping_msg = (PingMsg)recv.receive(); //wait for ping msg

            // Record the PingMsg's counter value then display it on the LEDs
            reply_msg.count = ping_msg.count;

            // leds.set(i++);
            leds.set(ping_msg.count);

            // Send the reply
            sender.send( reply_msg );
        }

    }

}

