/*
 * UNPUBLISHED PROPRIETARY INFORMATION
 * Copyright (c) 2007-2008 Sentilla Corporation
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Sentilla Corporation ("Confidential Information"). Disclosure of this
 * Confidential Information is prohibited, and its use shall be in
 * compliance with terms of the license agreement with Sentilla Corporation.
 */
import javax.measure.quantity.Acceleration;
import javax.measure.unit.SI;
import com.sentilla.platform.tmote.AccelerationSensor;
import com.sentilla.system.Leds;
import com.sentilla.system.LedsDriver;
import com.sentilla.system.Sensor;
import com.sentilla.system.SensorDriver;

/**
 * AcceleratorButton uses an acceleration sensor as a button.  Shaking the mote
 * is equivalent to pushing a button.  Uses a while loop to block and wait for
 * the accelerometer to move over a threshold.  The mote must shake in the Y-axis.
 *
 */
public class AcceleratorButton {
    public final static double RATE = 10;
    private static final int TIME_INTERVAL = 100;
    Sensor<Acceleration> accel;

    /**
     * Demonstrates how the AcceleratorButton works.  Shake the mote to toggle all the
     * LEDs on the mote.
     * 
     * @throws Exception
     */
    public static void motemain() throws Exception {
        Leds leds = LedsDriver.create();

        // Startup sequence to indicate the mote has the app
        for (int i = 0; i<=8; i++) {
            leds.set(255>>i);
            Thread.sleep(100);
        }

        // Create the button 
        AcceleratorButton button = new AcceleratorButton();

        while(true) {
            // Block until the mote shakes
            button.shake();

            // Toggle all the LEDs 
            leds.toggle(255);

            // Sleep here to keep the button from pressing over and over
            Thread.sleep(500);
        }
    }

    /**
     * Construct the button and create the sensor.
     *
     */
    public AcceleratorButton() {
        accel = SensorDriver.create("yaxis", Acceleration.class);
        ((AccelerationSensor)accel).setGRange(AccelerationSensor.G_RANGE_2);
    }

    /**
     * Returns when the mote shakes.
     *
     */
    public void shake() {
        try {
            while (true) {
                if (Math.abs(accel.read().doubleValue(SI.METER_PER_SQUARE_SECOND)) > RATE) { 
                    break;
                }
                Thread.sleep(TIME_INTERVAL);
            }
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }
}
