/*
 * UNPUBLISHED PROPRIETARY INFORMATION
 * Copyright (c) 2007 Sentilla Corporation
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Sentilla Corporation ("Confidential Information"). Disclosure of this
 * Confidential Information is prohibited, and its use shall be in
 * compliance with terms of the license agreement with Sentilla Corporation.
 */

import java.io.Serializable;

import javax.measure.Measurable;
import javax.measure.quantity.ElectricPotential;

import com.sentilla.net.Mac64Address;
import com.sentilla.net.Sender;
import com.sentilla.net.SenderDriver;
import com.sentilla.platform.tmote.VoltageAdc;
import com.sentilla.system.Sensor;

/**
 * Sends an A/D conversion in a message. This simple mote application
 * demonstrates use of an ADC port.
 *
 * This source code is from the ADC Application Tutorial for Sentilla Work.
 *
 * @author <a href="mailto:info@sentilla.com">Sentilla Corporation</a>
 */
public class MoteAdcApp {

    /**
     * The PotMessage class contains the source ID of the reporting mote and
     * sensor reading to be sent through the radio.
     */
    public static class PotMessage implements Serializable {
        public long id;
        public Measurable<ElectricPotential> PotReading;
    }

    /**
     * motemain is the application entry point that is executed when the
     * application is installed onto a mote.
     *
     * @throws InterruptedException
     *             Exit if interrupt() is called on this thread.
     */
    public static void motemain() throws InterruptedException {

        // Directly instantiate a VoltageAdc device corresponding to ADC
        // Port 3 of the MSP430 on the mote.
        Sensor<ElectricPotential> pot = new VoltageAdc(VoltageAdc.PORT_A3);

        // Use the Protocol factory to create a sender to send our message
        // through the default communication device.
        Sender sender = SenderDriver.create("local");

        // Create an instance of the message to send.
        PotMessage msg = new PotMessage();

        // Get the mac address of this mote
        msg.id = Mac64Address.getLocalAddress().longValue();

        // We are done initializing drivers and variables. Now, repeat this task
        // until the application is removed.
        while (true) {

            // Collect a new sensor reading from the potentiometer device.
            msg.PotReading = pot.read();

            // Send the message through the default communication device.
            sender.send(msg);

            // Wait 2000 milliseconds.
            Thread.sleep(2000);

            // If Thread.sleep throws InterruptedException, then motemain will
            // exit, which would be the expected behavior of calling interrupt()
            // on this thread.
        }
    }
}
