/*
 * UNPUBLISHED PROPRIETARY INFORMATION
 * Copyright (c) 2007-2008 Sentilla Corporation
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Sentilla Corporation ("Confidential Information"). Disclosure of this
 * Confidential Information is prohibited, and its use shall be in
 * compliance with terms of the license agreement with Sentilla Corporation.
 */


import java.lang.Math;
import com.sentilla.system.DigitalPin;
import com.sentilla.system.DigitalPinDriver;

/**
 * This sample application demonstrates how to use the accelerometer.  
 * The JCreate LEDs will fall down in the direction the mote is tilted.
 * This application only reads data from the Y-axis.  All other axes are 
 * ignored.
 * 
 * Note: the mote must be laying flat and facing up when booting (for calibration.)
 * 
 * @author Sentilla Corporation
 *
 */
public class MoteLevel
{
    /**
     * Main class that runs the application.  
     * 
     * @throws InterruptedException
     */
    public static void motemain() throws InterruptedException
    {
        // Currently lit LED
        int currentLed = 0;
        
        // Next LED to light
    	int nextLed = 7;
    	
    	// LED that is currently being changed
    	int movingLed;
    	
    	// The axis used by this sample.  Currently the Y-axis
    	double axisOfInterestReading = 0;
    	
    	// Flag to keep the LEDs moving
    	boolean keepLoop = false;
    	
    	// Instantiate the accelerometer
    	// Let the Accelerometer know that we're only interested in Y-axis readings
    	Accelerometer accel = new Accelerometer(false, true, false);		
        
        // array for reading the sensor values
        float[] readings = new float[1];

    	// To increase speed, access the LED pins directly rather than through the LED interface
    	DigitalPin ledPort = DigitalPinDriver.create(0x50);
    	
    	// Set the current lit LED to the middle LED
    	currentLed = 3;
    	ledPort.writePort((byte)0xFF, (byte)(0x1 << currentLed));

    	// Repeat this task until the application is removed.
        while(true)
        {
        	movingLed = currentLed;
        	
        	// Read the accelerometer
        	accel.getMultipleReadings(readings);
        	
        	// Extract only the Y axis
        	axisOfInterestReading = readings[0];

        	// Determine which Led the reading corresponds to:
        	nextLed = (int)Math.floor(axisOfInterestReading / 0.25) + 4;
        	nextLed = Math.min(7, nextLed);			// Protects against setting the wrong pin
        	nextLed = Math.max(0, nextLed);

        	// Keep looping until the appropriate LED is lit
        	keepLoop = (currentLed != nextLed);
        	while(keepLoop)
        	{
        	    // Set the moving LED to one of the LEDs next to the current one
        		movingLed += (nextLed > currentLed)? 1 : - 1;
        		
        		// Write the value to the LEDs
        		ledPort.writePort((byte)0xFF, (byte)(1 << movingLed));
        		
        		// Update the flag
        		keepLoop = (movingLed != nextLed);
        	}
        	// Set current LED to the lit LED
        	currentLed = nextLed;
        }
    }
}
