/*
 * UNPUBLISHED PROPRIETARY INFORMATION
 * Copyright (c) 2007-2008 Sentilla Corporation
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Sentilla Corporation ("Confidential Information"). Disclosure of this
 * Confidential Information is prohibited, and its use shall be in
 * compliance with terms of the license agreement with Sentilla Corporation.
 */

import com.sentilla.platform.tmote.Adc;
import javax.measure.Measurable;
import javax.measure.quantity.Dimensionless;
import javax.measure.unit.Unit;
import com.sentilla.measure.FloatMeasure;

/**
 * Creates a device class MotePotSensor for a potentiometer. This
 * class is a simple illustration of device customization.
 *
 * This source code is from the ADC Driver Tutorial for Sentilla Work.
 *
 * @author <a href="mailto:info@sentilla.com">Sentilla Corporation</a>
 */
public class MotePotSensor extends Adc<Dimensionless> {

    /** Construct a default potentiometer sensor. */
    public MotePotSensor() {
        super(PORT_A3, REFVOLT_1_5 );
    }

    /**
     * Construct a default potentiometer sensor.
     *
     * @param refvolt
     *            Reference voltage enumeration, see VoltageAdc for valid
     *            values.
     */
    public MotePotSensor(byte refvolt) {
        super(PORT_A3, refvolt);
    }

    public class Percentage extends FloatMeasure<Dimensionless>  {
        public Percentage( double v ) { super(v); }
        public Unit<Dimensionless> getUnit() { return Dimensionless.UNIT; }
    }

    /**
     * Take a new reading for the potentiometer sensor and return the 
     * sliding terminal voltage as a percentage of the limiting (reference) voltage.
     */

    public Measurable<Dimensionless> getResult() {
        double div = (refvolt == Adc.REFVOLT_1_5) ? 1.5 : 2.5;
        return new Percentage(getVoltage() / div);
    }
}

