import java.io.Serializable;

import javax.measure.Measurable;
import javax.measure.quantity.ElectricPotential;

import com.sentilla.net.Mac64Address;
import com.sentilla.net.Sender;
import com.sentilla.net.SenderDriver;
import com.sentilla.system.Leds;
import com.sentilla.system.LedsDriver;
import com.sentilla.system.Sensor;
import com.sentilla.system.SensorDriver;

/**
 * Sends a voltage sensor reading in a periodic report message.
 * @author  <a href="mailto:info@sentilla.com">Sentilla Corporation</a>
 */

public class MoteSenseNSend {

  public static class DataMessage implements Serializable {

    public long moteId;
    public short count;
    public Measurable<ElectricPotential> voltage;
  }

  /**
   * motemain is the entry point that is executed when the application is
   * installed onto a mote.
   *
   * @throws InterruptedException
   *             Exit if interrupt() is called on this thread.
   */
  public static void motemain() throws InterruptedException {

    // Use Driver factories to get the device ID and to create device
    // instances for Leds, Sender, and various Sensors.

    long id = Mac64Address.getLocalAddress().longValue();
    Leds leds = LedsDriver.create();

    // Create a sender
    Sender sender = SenderDriver.create("local");

    // Create the voltage sensor
    Sensor<ElectricPotential> voltage = SensorDriver.create("volt", ElectricPotential.class);

    // Allocate a local counter and an instance of the message data to send.
    short count = 0;
    DataMessage datamsg = new DataMessage();

    while (true) {

      // Increment the counter and render it to the LEDs.
      count++;
      leds.set(count);
      Thread.sleep(5000);

      // Prepare datamsg with the moteId, count,
      // and voltage readings.

      datamsg.moteId = id;
      datamsg.count = count;
      datamsg.voltage = voltage.read();

      // Send datamsg.
      sender.send(datamsg);
    }
  }
}
