/*
 * UNPUBLISHED PROPRIETARY INFORMATION
 * Copyright (c) 2007-2008 Sentilla Corporation
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Sentilla Corporation ("Confidential Information"). Disclosure of this
 * Confidential Information is prohibited, and its use shall be in
 * compliance with terms of the license agreement with Sentilla Corporation.
 */


import java.io.Serializable;

import javax.measure.quantity.Dimensionless;

import com.sentilla.net.Mac64Address;
import com.sentilla.net.Sender;
import com.sentilla.net.SenderDriver;
import com.sentilla.platform.tmote.Adc;
import com.sentilla.system.Drivers;
import com.sentilla.system.Sensor;
import com.sentilla.system.SensorDriver;

/**
 * Sends an A/D conversion in a message. This simple mote application
 * demonstrates mote customization using drivers.
 *
 * This source code is from the ADC Driver Tutorial for Sentilla Work.
 *
 * @author <a href="mailto:info@sentilla.com">Sentilla Corporation</a>
 */
public class MoteSensorAppDriver extends com.sentilla.system.SensorDriver {

    // Instantiate a user-defined potentiometer device limited to 1.5V
    public com.sentilla.system.Sensor newSensor() {
        return new MotePotSensor( Adc.REFVOLT_1_5 );
    }

    // Bootstrapping method of the Driver factory that internally names the
    // user-defined potentiometer device
    public String getDriverName( int n ) {
        if( n == 0 ) return "devpot";
        return null;
    }

    // Type-indicator method of the Driver factory that declares the return
    // type of the user-defined potentiometer class
    public Class<Dimensionless> getQuantityClass() {
    	return Dimensionless.class;
    }

    /**
     * The PotMessage class contains the source ID of the reporting mote and
     * sensor reading to be sent through the radio.
     */
    public static class PotMessage implements Serializable {
        public long id;
        double PotReading;
    }


    /**
     * motemain is the entry point that is executed when the application is
     * installed onto a mote.
     *
     * @throws InterruptedException
     *             Exit if interrupt() is called on this thread.
     */
    public static void motemain() throws InterruptedException {

	// Instantiate and install driver class
        Drivers.addDriver( new MoteSensorAppDriver() );

        // Use the Sensor factory to create a user-defined potentiometer device
        Sensor<Dimensionless> pot = SensorDriver.create("devpot", Dimensionless.class);

        // Use the Protocol factory to create a sender to send our message
        // through the default communication device.
        Sender sender = SenderDriver.create("local");

        // Create an instance of the message to send.
        PotMessage msg = new PotMessage();

        // Get the mac address of this mote
        msg.id = Mac64Address.getLocalAddress().longValue();


        // Now, repeat this task until the application is removed.
        while ( true ) {

            // Collect a new sensor reading from the user-defined potentiometer device.
            msg.PotReading = pot.read().doubleValue(Dimensionless.UNIT);

            // Send the message through the default communication device.
            sender.send( msg );

            // Put this thread to sleep for 2000ms.
            Thread.sleep(2000);

            // If Thread.sleep throws InterruptedException, then motemain will
            // exit, which would be the expected behavior of calling interrupt()
            // on this thread.
        }
    }

}
