/*
 * UNPUBLISHED PROPRIETARY INFORMATION
 * Copyright (c) 2007-2008 Sentilla Corporation
 * All rights reserved.
 *
 * This software is the confidential and proprietary information of
 * Sentilla Corporation ("Confidential Information"). Disclosure of this
 * Confidential Information is prohibited, and its use shall be in
 * compliance with terms of the license agreement with Sentilla Corporation.
 */

import java.io.Serializable;

import com.sentilla.net.Receiver;
import com.sentilla.net.ReceiverDriver;
import com.sentilla.net.Sender;
import com.sentilla.net.SenderDriver;
import com.sentilla.system.Leds;
import com.sentilla.system.LedsDriver;


/**
 * Example application that sends messages between motes.  
 * 
 * Any mote that receives a MoteTestProtocol.SetSenderMessage
 * will be a transmitter and all other motes will be receivers.  The
 * transmitter will transmit a message containing a count and display the
 * current count on it's LEDs.  The receivers will display the count in any
 * message they receive.
 */
public class MoteSimpleComm {

    /**
     * Application message.  This is the message
     * that will be sent.
     */
    public static class MyMessage implements Serializable {
        public int count = 0;
    }

    /**
     * Main Sender Thread
     */
    public static class SendThread extends Thread {
        public boolean rcvdMessage = false;
        
        public void run() {
            // Create a Leds instance
            Leds leds = LedsDriver.create();

            // Create a Sender instance
            Sender sender = SenderDriver.create("local");
            
            // Create the message object
            MyMessage msg = new MyMessage();

            // Set the LEDs to indicate that the mote is ready
            leds.set(255);

            // Create a sample button using the accelerometer
            AcceleratorButton button = new AcceleratorButton();

            // Block until the mote shakes
            button.shake();
            
            // If already receiving message, then don't send any
            if (rcvdMessage)
                this.stop();
            
            // Main sender execution.
            while (true) {
                // Update a counter in the message.
                msg.count++;

                // Send the message.
                sender.send(msg);

                // Set the LEDs to the message count.
                leds.set(msg.count);

                // Sleep for five seconds between each transmit
                try {
                    Thread.sleep(2000);
                } catch (InterruptedException e) {
                }

            }
        }
    }
    
    /**
     * Application that will send messages between motes.
     */
    public static void motemain() throws InterruptedException {

        // Create a new Leds object.
        Leds leds = LedsDriver.create();

        // Create and start send thread.
        // Start sending if the mote shakes.
        SendThread st = new SendThread();
        st.start();

        // Create a Receiver object for the MyMessage class.  This
        // will return any messages received by the mote that matches
        // the class MyMessage, regardless of how the message was
        // received.
        Receiver receiver = ReceiverDriver.create(MyMessage.class);
        
        // Main receiver execution.
        while(true) {
            // Block program execution until a message is received
            MyMessage msg = (MyMessage)receiver.receive();
            
            // Set the received flag to true so this mote doesn't start transmitting
            st.rcvdMessage = true;
            
            // Set the LEDs to the received message count
            leds.set(msg.count);
        }
    }
}
